@@ -31,11 +31,13 @@
 #' @param boot A logical value specifying whether the confidence intervals are obtained
 #'     by the delta method or by percentile bootstrap.
 #' @param nboot   The number of bootstrap replications used to obtain the confidence intervals if \code{boot = TRUE}.
+#'     By default \code{nboot = 1000}.
 #' @param bootseed The value of the initial seed (positive integer) for random number generation if \code{boot = TRUE}.
 #' @param confcoef A number between 0 and 1 for the confidence coefficient (ex.: 0.95) of the interval estimates.
 #' @param hvalue_y The value corresponding to the high level of the outcome. If the outcome is already coded
 #'     as a numerical binary variable taking 0 or 1 values, then by default \code{hvalue_y = 1}.
-#' @param yprevalence The prevalence of the outcome in the population. Option used when case-control data are used.
+#' @param yprevalence The prevalence of the outcome in the population (a number between 0 and 1).
+#'     Option used when case-control data are used.
 #'     The low level of the outcome is treated as the control level.
 #' @param mf The value of the mediator at which the conditional controlled direct effect is computed. If it is not specified,
 #'      \code{mf} is fixed at the sample-specific mean of the mediator (default).
@@ -54,14 +56,24 @@
 #'
 #'     The Firth parameter allows to reduce the bias of the outcome logistic regression coefficients estimators when facing a problem of
 #'     separation or quasi-separation. The bias reduction is achieved by the \code{\link[brglm2]{brglmFit}} fitting method of the \emph{brglm2} package.
-#'     More precisely, estimates are obtained using a penalized maximum likelihood with a Jeffreys prior penalty, which is equivalent to the mean
+#'     More precisely, estimates are obtained via penalized maximum likelihood with a Jeffreys prior penalty, which is equivalent to the mean
 #'     bias-reducing adjusted score equation approach in Firth (1993).
 #'
 #'     When the data come from a case-control study, the \code{yprevalence} parameter should be used and its value ideally correspond to the true outcome prevalence.
-#'     \code{exactmed()} accounts for the ascertainment in the sample by employing weighted regression techniques that use inverse probability weighting (IPW)
+#'     \code{exactmed_c()} accounts for the ascertainment in the sample by employing weighted regression techniques that use inverse probability weighting (IPW)
 #'     with robust standard errors. These errors are obtained via the \code{\link[sandwich]{vcovHC}} function of the R package \emph{sandwich}.
 #'     Specifically, we use the HC3 type covariance matrix estimator (default type of the \code{\link[sandwich]{vcovHC}} function).
 #'
+#'     For the mediation effects expressed on the multiplicative scales (odds ratio, OR; risk ratio, RR), the \code{exactmed_c()} function
+#'     returns delta method confidence intervals by exponentiating the lower and upper limits of the normal confidence intervals obtained
+#'     for the logarithmic transformations of the effects. The \code{exactmed_c()} function also provides the estimated standard errors of
+#'     natural and controlled direct effects estimators that are not log-transformed, where those are derived using a first order Taylor expansion
+#'     (e.g., \eqn{\hat{SE}(\hat{OR})=\hat{OR} \times \hat{SE}(\log(\hat{OR}))}). The function performs Z-tests (null hypothesis: there is no effect)
+#'     computing the corresponding two-tailed \emph{p}-values. Note that for the multiplicative scales, the standard scores (test statistics)
+#'     are obtained by dividing the logarithm of an effect estimator by the estimator of the corresponding standard error
+#'     (e.g., \eqn{\log(\hat{OR}) / \hat{SE}(\log(\hat{OR}))}). No log-transformation is applied when working on the risk difference scale.
+#'
+#'
 #' @return An object of class \code{results_c} is returned:
 #' \item{ne.or}{Natural effects estimates on OR scale.}
 #' \item{ne.rr}{Natural effects estimates on RR scale.}
@@ -87,10 +99,10 @@
 #' \emph{Observational Studies}.2018;4(1):193-216.
 #'
 #' Samoilenko M, Lefebvre G. Parametric-regression-based causal mediation analysis of binary outcomes and binary mediators:
-#' moving beyond the rareness or commonness of the outcome, \emph{American Journal of Epidemiology}.2021;190(9):1846-1858. \doi{10.1093/aje/kwab055}.
+#' moving beyond the rareness or commonness of the outcome. \emph{American Journal of Epidemiology}.2021;190(9):1846-1858. \doi{10.1093/aje/kwab055}.
 #'
 #' Samoilenko M, Lefebvre G. An exact regression-based approach for the estimation of the natural direct and indirect effects
-#' with a binary outcome and a continuous mediator. \emph{Statistics in Medicine}.2022;1-35. \doi{10.1002/sim.9621}.
+#' with a binary outcome and a continuous mediator. \emph{Statistics in Medicine}.2023; 42(3): 353–387. \doi{10.1002/sim.9621}.
 #'
 #' Firth D. Bias reduction of maximum likelihood estimates.
 #' \emph{Biometrika}.1993;80:27-38. \doi{10.2307/2336755}.
@@ -247,7 +259,7 @@ exactmed_c <- function(data, a, m, y, a1, a0, m_cov = NULL, y_cov = NULL, m_cov_
           result <- vector("list", length = 8)
           result[[1]] <- Mreg$coefficients
           result[[2]] <- Yreg$coefficients
-          result[[3]] <- sum(Mreg$residuals^2)/Mreg$df.residual
+          result[[3]] <- sum(cc_weights * Mreg$residuals^2)/Mreg$df.residual
           result[[4]] <- Mreg$df.residual
           result[[5]] <- vcovHC(Mreg)
           result[[6]] <- vcovHC(Yreg)
@@ -267,7 +279,7 @@ exactmed_c <- function(data, a, m, y, a1, a0, m_cov = NULL, y_cov = NULL, m_cov_
           result <- vector("list", length = 8)
           result[[1]] <- Mreg$coefficients
           result[[2]] <- Yreg$coefficients
-          result[[3]] <- sum(Mreg$residuals^2)/Mreg$df.residual
+          result[[3]] <- sum(cc_weights * Mreg$residuals^2)/Mreg$df.residual
           result[[4]] <- Mreg$df.residual
           result[[5]] <- vcovHC(Mreg)
           result[[6]] <- vcovHC(Yreg)
@@ -695,14 +707,15 @@ exactmed_c <- function(data, a, m, y, a1, a0, m_cov = NULL, y_cov = NULL, m_cov_
     ContEffm[3, ] <- c(RDm, seRDm, CI_RDm, pvalueRDm)
 
 
-    results <- vector("list", 6)
+    results <- vector("list", 7)
     names(results) <- c(
       "ne.or",
       "ne.rr",
       "ne.rd",
       "cde",
       "med.reg",
-      "out.reg"
+      "out.reg",
+      "m.value"
     )
 
     OR <- as.data.frame(OR)
@@ -721,12 +734,15 @@ exactmed_c <- function(data, a, m, y, a1, a0, m_cov = NULL, y_cov = NULL, m_cov_
     results[[4]] <- cbind(round(ContEffm[1:4], digits = 5), ContEffm[5])
     results[[5]] <- beta_theta_coef[[7]]
     results[[6]] <- beta_theta_coef[[8]]
+    results[[7]] <- mf
 
     class(results) <- c("results_c", "list")
 
   } else {
 
     if(is.null(yprevalence)) {
+      cc_weights <- 1
+
       repli_data <- function(data, n, y) {
         vboot <- sample(1:n, n, replace = TRUE)
         DATAboot <- data[vboot, ]
@@ -813,7 +829,7 @@ exactmed_c <- function(data, a, m, y, a1, a0, m_cov = NULL, y_cov = NULL, m_cov_
 
     betacoef <- beta_theta_coef_ini$Mreg$coefficients
     thetacoef <- beta_theta_coef_ini$Yreg$coefficients
-    varcoef <- sum(beta_theta_coef_ini$Mreg$residuals^2) / beta_theta_coef_ini$Mreg$df.residual
+    varcoef <- sum(cc_weights * beta_theta_coef_ini$Mreg$residuals^2) / beta_theta_coef_ini$Mreg$df.residual
 
     gg <- function(a, b, betav, varcoef, covmv, thetav, covyv, interaction){
 
@@ -945,7 +961,7 @@ exactmed_c <- function(data, a, m, y, a1, a0, m_cov = NULL, y_cov = NULL, m_cov_
 
       betacoef <- beta_theta_coef$Mreg$coefficients
       thetacoef <- beta_theta_coef$Yreg$coefficients
-      varcoef <- sum(beta_theta_coef$Mreg$residuals^2) / beta_theta_coef$Mreg$df.residual
+      varcoef <- sum(cc_weights * beta_theta_coef$Mreg$residuals^2) / beta_theta_coef$Mreg$df.residual
 
       P10 <- gg(a1, a0, betacoef,varcoef, mean_covmv, thetacoef,mean_covyv,interaction)
       P00 <- gg(a0, a0, betacoef,varcoef, mean_covmv, thetacoef,mean_covyv,interaction)
@@ -1049,7 +1065,7 @@ exactmed_c <- function(data, a, m, y, a1, a0, m_cov = NULL, y_cov = NULL, m_cov_
     ContEffm[2, ] <- c(RRm, seRRm, CI_RRm)
     ContEffm[3, ] <- c(RDm, seRDm, CI_RDm)
 
-    results <- vector("list", 13)
+    results <- vector("list", 14)
     names(results) <- c(
       "ne.or",
       "ne.rr",
@@ -1063,7 +1079,8 @@ exactmed_c <- function(data, a, m, y, a1, a0, m_cov = NULL, y_cov = NULL, m_cov_
       "boot.cde.rd",
       "boot.ind",
       "med.reg",
-      "out.reg"
+      "out.reg",
+      "m.level"
     )
 
     results[[1]] <- round(OR, digits = 5)
@@ -1079,6 +1096,7 @@ exactmed_c <- function(data, a, m, y, a1, a0, m_cov = NULL, y_cov = NULL, m_cov_
     results[[11]] <- indiceboot
     results[[12]] <- beta_theta_coef_ini$Mreg
     results[[13]] <- beta_theta_coef_ini$Yreg
+    results[[14]] <- mf
 
     class(results) <- c("results_c", "list")
 
