@@ -8,7 +8,9 @@
       if (is.factor(data[[i]])) {
         if (i %in% names(my_cov_cond)) {
           if (!(my_cov_cond[[i]] %in% levels(data[[i]]))) {
-            stop("Invalid value for ", i, " covariate")
+            stop("Invalid value for ", i, " covariate.
+                 Make sure that 'm_cov_cond' and 'y_cov_cond' are list-type vectors
+                 if there is a mixture of numerical and categorical variables")
           }
           auxv <- vector("numeric", nlevels(data[[i]]) - 1L)
           auxl <- which(levels(data[[i]]) == my_cov_cond[[i]]) - 1
@@ -24,7 +26,9 @@
       } else {
         if (i %in% names(my_cov_cond)) {
           if (!(is.vector(my_cov_cond[[i]], mode = "numeric") && length(my_cov_cond[[i]]) == 1L)) {
-            stop("Invalid value for ", i, " covariate")
+            stop("Invalid value for ", i, " covariate.
+                 Make sure that 'm_cov_cond' and 'y_cov_cond' are list-type vectors
+                 if there is a mixture of numerical and categorical variables")
           }
           mean_covv <- c(mean_covv, my_cov_cond[[i]])
         } else {
